//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#ifdef G4MULTITHREADED
  #include "G4MTRunManager.hh"
#else
  #include "G4RunManager.hh"
#endif

//#include "G4RunManager.hh"

#include "G4UImanager.hh"
#include "G4UIQt.hh"
#include "Randomize.hh"
#include <time.h>
#include <sys/resource.h>

#ifdef G4VIS_USE
#include "G4VisExecutive.hh"
#endif

#ifdef G4UI_USE
#include "G4UIExecutive.hh"
#endif

#include "ActionInitialization.hh"
#include "DetectorConstruction.hh"
#include "PhysicsList.hh"
#include "G4PhysicalConstants.hh"

int main(int argc,char** arg)
{   
 // choose the Random engine
 G4Random::setTheEngine(new CLHEP::RanecuEngine);
 G4long seed = time(NULL);
 G4Random::setTheSeed(seed);
 //G4Random::showEngineStatus();

 // improvement of the almost-random process
 G4int fRandInt=0;
 G4double fRandDouble=0.;
 std::ifstream fRandomFile;

 fRandomFile.open("/dev/urandom", std::ios::in | std::ios::binary);
 if(!fRandomFile.is_open()){G4cout<< "impossible to open /dev/random file"<<G4endl;abort();}
 fRandomFile.read(reinterpret_cast<char *>(&fRandInt), 1);
 fRandomFile.close();

 fRandInt=int(fabs(fRandInt))%10000;
 for(G4int i=0;i<fRandInt;i++)fRandDouble=G4UniformRand();
 G4Random::showEngineStatus();

 // Construct the default run manager
 
/*
 #ifdef G4MULTITHREADED
  G4MTRunManager* runManager = new G4MTRunManager;

  // By default, only one thread for aberration coefficient calculation ("coef*" macros)
  //
  // For high statistics (no aberration coefficient calculation, "image*" & "grid*" macros), 
  // switch to more threads 
    
 // runManager->SetNumberOfThreads(NbThread);
  //runManager->SetNumberOfThreads(2);

 #else
  G4RunManager* runManager = new G4RunManager;
 #endif
*/ 

 G4RunManager* runManager = new G4RunManager;

 // Set mandatory initialization classes
 //


 DetectorConstruction* World = new DetectorConstruction();

 runManager->SetUserInitialization(World);
 
 G4VUserPhysicsList* physics = new PhysicsList();
 runManager->SetUserInitialization(physics);
   
 // Set user action classes

 runManager->SetUserInitialization(new ActionInitialization(World));
  
 #ifdef G4VIS_USE
 // Visualization manager
 //
 G4VisManager* visManager = new G4VisExecutive;
 visManager->Initialize();
 #endif 

 // Initialize G4 kernel
 //
 runManager->Initialize();

 // Get the pointer to the User Interface manager
 //
 G4UImanager* UImanager = G4UImanager::GetUIpointer();
 UImanager->ApplyCommand("/tracking/verbose 0");

if ((arg[1])&&(!arg[2]))   // Define UI session for interactive mode
 { 
  G4String fileName = "run.mac";
  G4String command = "/control/execute ";
  UImanager->ApplyCommand(command+fileName);
 }

 if(arg[2])          // Batch mode
 {
  G4String fileName = arg[2];
   #ifdef G4UI_USE
  // char** argv = fileName;
   G4UIExecutive * ui = new G4UIExecutive(argc,arg);
   #ifdef G4VIS_USE
    UImanager->ApplyCommand("/control/execute "+fileName); 
   #endif 
   ui->SessionStart();
   delete ui;
   #endif
 }

 #ifdef G4VIS_USE
  delete visManager;
 #endif 
 delete runManager;
       

 return 0;
}