//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#ifndef DetectorConstruction_h
#define DetectorConstruction_h 1

#include "globals.hh"
#include "G4SystemOfUnits.hh"
#include "G4VUserDetectorConstruction.hh"
#include "G4Material.hh"
#include "G4Tubs.hh"
#include "G4Box.hh"
#include "G4Cons.hh"
#include "G4LogicalVolume.hh"
#include "G4PVPlacement.hh"
#include "G4VisAttributes.hh"
#include "G4Colour.hh"
#include "G4GeometryManager.hh"
#include "G4GeometryTolerance.hh"
#include "G4PhysicalConstants.hh"
#include "G4NistManager.hh"

 const  G4float Sample_Thick = 0.250*mm;
 const  G4float Sample_div = 0.010*mm;
 const  G4float Sample_densi = 1.8*g/cm3;
 const  G4float Sample_diam = 7.95*mm;

 const G4float fShutter = 0.00*mm;
 const G4float fSiliconeOil = 0.03*mm;
 
 const G4String result = "Szb_250_8mm_noCup";
 const G4String spectre = "Sr90_spectra.txt";

class DetectorConstruction : public G4VUserDetectorConstruction
{
  public:
    DetectorConstruction();
    virtual ~DetectorConstruction();
     	
  public:
    virtual G4VPhysicalVolume* Construct();
     
  private:
    void DefineMaterials();
    void SetupGeometry();

    G4Material* CreateNewComponent(G4int Component_No);
    void CreateNewMaterial(G4int Material_No);


      
    G4VPhysicalVolume* worldPhy;
    G4double DWx,DWy,DWz,DWmax;

    G4bool constructed;
                  
};




#endif

