//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "DetectorConstruction.hh"
#include "G4PVReplica.hh"

DetectorConstruction::DetectorConstruction()
:constructed(false)
{
    ;
}

DetectorConstruction::~DetectorConstruction()
{
 delete worldPhy;
}

G4VPhysicalVolume* DetectorConstruction::Construct()
{
 if(!constructed)
 { 
  G4double fWorldLength = 200*mm;
  G4GeometryManager::GetInstance()->SetWorldMaximumExtent(fWorldLength);
  DefineMaterials();
  SetupGeometry();
  constructed = true;  
 }
 return worldPhy;
}

void DetectorConstruction::DefineMaterials()
{ 
 G4String name, symbol;             //a=mass of a mole;
 G4double density;            //z=mean number of protons;  
  
 G4Element* H  = new G4Element(name="Hydrogen",symbol="H" ,  1.,  1.01*g/mole);

 G4Element* N  = new G4Element(name="Nitrogen",symbol="N" ,  7., 14.01*g/mole);

 G4Element* O  = new G4Element(name="Oxygen"  ,symbol="O" ,  8.,  16.00*g/mole);

 G4Element* C  = new G4Element(name="Carbon"  ,symbol="C" ,  6.,  12.0107*g/mole);

 G4Element* Si = new G4Element(name="Silicium", symbol="Si",14.,  28.09*g/mole);

 G4Element* K = new G4Element(name="Potassium", symbol="K",  19,  39.10*g/mole);

 G4Element* Al = new G4Element(name="Aluminum", symbol="Al", 13,  26.98*g/mole);

 G4Element* Fe = new G4Element(name="Iron", symbol="Fe",  26,  55.85*g/mole);

 G4Element* Ni = new G4Element(name="Nickel", symbol="Ni",  28, 58.6934*g/mole);

 G4Element* Mg = new G4Element(name="Magnesium", symbol="Mg",  12, 24.31*g/mole);

 G4Element* Ca = new G4Element(name="Calcium", symbol="Ca",  20,  40.08*g/mole);

 G4Element* Na = new G4Element(name="Sodium", symbol="Na",  11,  22.99*g/mole);

 G4Element* Zr = new G4Element(name="Zirconium", symbol= "Zr",  39,  91.224*g/mole);

 G4Element* P = new G4Element(name="Phosphore", symbol= "P",  15,  30.973*g/mole);

 G4Element* Pb = new G4Element(name="Lead",symbol= "Pb", 82,  207.19*g/mole);

 G4Element* Cr = new G4Element(name="Chromium",symbol= "Cr", 24,  51.9961*g/mole);

 G4Element* Mn = new G4Element(name="Manganese",symbol= "Mn", 25,  54.938*g/mole);

 G4Element* Sr = new G4Element(name="Strontium",symbol= "Sr", 38,  87.62*g/mole);

 G4Element* Ti = new G4Element(name="Titanium",symbol= "Ti", 22,  47.867*g/mole);
 
  G4Element* S = new G4Element(name="Sulfur",symbol= "S", 16,  32.065*g/mole);
  
    G4Element* Cu = new G4Element(name="Copper",symbol= "Cu", 29,  63.546*g/mole);

 G4int ncomponents, natoms;
 G4double fractionmass=0;  

 G4Material* water = new G4Material(name="Water", density=1.000*g/cm3, ncomponents=2);
 water->AddElement(H, natoms=2);
 water->AddElement(O, natoms=1);

 G4Material*SiO2 = new G4Material("Silice", density= 2.65*g/cm3, ncomponents=2);
 SiO2->AddElement(Si, natoms=1);
 SiO2->AddElement(O, natoms=2); 
   
 G4Material* Al2O3 = new G4Material("Alumine", density= 4.0*g/cm3, ncomponents=2);
// G4Material* Al2O3 = new G4Material("Alumine", density= Sample_densi, ncomponents=2);
 Al2O3->AddElement(Al, natoms=2);
 Al2O3->AddElement(O, natoms=3);
  
 G4Material* KF = new G4Material("K-Feldspar", density= 2.60*g/cm3, ncomponents=4);
 KF->AddElement(Al,fractionmass = 0.0969);
 KF->AddElement(O, fractionmass = 0.4599);
 KF->AddElement(Si, fractionmass = 0.3027);
 KF->AddElement(K, fractionmass = 0.1405);
 
 density = 1.290*mg/cm3; 
 G4Material* air = new G4Material(name="Air", density, ncomponents=2);
 air->AddElement(N, fractionmass=0.78);
 air->AddElement(O, fractionmass=0.22);

 G4Material* vacuum = new G4Material("Vacuum", 1, 1.00794*g/mole,1.0E-25*g/cm3, kStateGas, 0.1*kelvin, 1.0E-19*pascal);

 G4Material* lead= new G4Material(name="Lead", 11.35*g/cm3, ncomponents=1);
 lead->AddElement(Pb, natoms=1);

 G4Material* aluminum= new G4Material(name="aluminum", 2.70*g/cm3, ncomponents=1);
 aluminum->AddElement(Al, natoms=1);

 G4Material* StL_steel= new G4Material(name="stainless_steel", 7.9*g/cm3, ncomponents=9);
 StL_steel->AddElement(Fe, fractionmass=0.5063);
 StL_steel->AddElement(Cr, fractionmass=0.25);
 StL_steel->AddElement(C, fractionmass=0.002);
 StL_steel->AddElement(Si, fractionmass=0.015);
 StL_steel->AddElement(Mn, fractionmass=0.02);
 StL_steel->AddElement(Ni, fractionmass=0.205);
 StL_steel->AddElement(P, fractionmass=0.00045);
 StL_steel->AddElement(S, fractionmass=0.00015);
 StL_steel->AddElement(N, fractionmass=0.0011);
 
  G4Material* Nickel200= new G4Material(name="Nickel200", 8.89*g/cm3, ncomponents=9);
 Nickel200->AddElement(Fe, fractionmass=0.00302);
 Nickel200->AddElement(Ti, fractionmass=0.00075);
 Nickel200->AddElement(C, fractionmass=0.00075);
 Nickel200->AddElement(Si, fractionmass=0.00015);
 Nickel200->AddElement(Mn, fractionmass=0.00226);
 Nickel200->AddElement(Ni, fractionmass=0.99);
 Nickel200->AddElement(Cu, fractionmass=0.00189);
 Nickel200->AddElement(S, fractionmass=0.00004);
 Nickel200->AddElement(Mg, fractionmass=0.00113);

 G4Material* SrTiO3= new G4Material(name="SrTiO3", 5.11*g/cm3, ncomponents=2);
 SrTiO3->AddElement(Sr, natoms=1);
 SrTiO3->AddElement(Ti, natoms=3);

 G4Material* PDMS= new G4Material(name="Polydimethylsiloxane ", 0.965*g/cm3, ncomponents=4);
 PDMS->AddElement(C, natoms=2);
 PDMS->AddElement(H, natoms=6);
 PDMS->AddElement(O, natoms=2);
 PDMS->AddElement(Si, natoms=1);

 G4Material* smokedSiO2= new G4Material(name="smokedSiO2", 1.8*g/cm3, ncomponents=2);
 smokedSiO2->AddElement(Si, natoms=1);
 smokedSiO2->AddElement(O, natoms=2);

 G4Material* SiliconeG = new G4Material(name="Silicone_Grease", 1.0*g/cm3, ncomponents=2);
 SiliconeG->AddMaterial(PDMS, fractionmass=0.958);
 SiliconeG->AddMaterial(smokedSiO2, fractionmass=0.042);

}

void DetectorConstruction::SetupGeometry()
{ 
 G4Material* air = G4Material::GetMaterial("Air");
 G4Material* lead = G4Material::GetMaterial("Lead");
 G4Material* steel = G4Material::GetMaterial("stainless_steel");
 G4Material* enamel = G4Material::GetMaterial("SrTiO3");
 G4Material* cupMat = G4Material::GetMaterial("Air");
 G4Material* SampleMat = G4Material::GetMaterial("Quartz");
 G4Material* GreaseMat = G4Material::GetMaterial("Silicone_Grease");
 G4Material* containerMat = G4Material::GetMaterial("Air");
 //     
 // World
 //    
    
 G4Box* worldSol = new G4Box("World",80*mm,80*mm,80*mm);

 // G4Tubs* worldSol  = new G4Tubs("World",0*mm,DWx /2.,DWz/2.,0.*deg,360.*deg);

 G4LogicalVolume* worldLog = new G4LogicalVolume(worldSol,air,"World");
 worldPhy = new G4PVPlacement(0,G4ThreeVector(),worldLog,"World",0,false,0);		
									
 G4VisAttributes* worldVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
 worldVisAtt->SetVisibility(true);
 worldLog->SetVisAttributes(worldVisAtt);
 
  // container
// G4Tubs* Container_Sol = new G4Tubs("Container",0.,17.5*mm,13.0*mm,0.,2*M_PI);
G4Tubs* Container_Sol = new G4Tubs("Container",0.,39.9*mm,13.0*mm,0.,2*M_PI);
 G4LogicalVolume* Container_Log = new G4LogicalVolume(Container_Sol,containerMat,"Container",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,1.0*mm),Container_Log ,"Container",worldLog,false,0,true);
 
 // G4Tubs* ContHole_Sol = new G4Tubs("ContainerHole",0.,12.5*mm,8.0*mm,0.,2*M_PI);
 G4Tubs* ContHole_Sol = new G4Tubs("ContainerHole",0.,39.9*mm,13.0*mm,0.,2*M_PI);
 G4LogicalVolume* ContHole_Log = new G4LogicalVolume(ContHole_Sol,air,"ContainerHole",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,0.),ContHole_Log ,"ContainerHole",Container_Log,false,0,true);
 
 G4Tubs* Disk_Sol = new G4Tubs("Disk",0.,39.9*mm,2.5*mm,0.,2*M_PI);
 G4LogicalVolume* Disk_Log = new G4LogicalVolume(Disk_Sol,containerMat,"Disk",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,-10.5),Disk_Log ,"Disk",ContHole_Log,false,0,true);
 
 // SST source shell
 G4Tubs* SSTshell_Sol = new G4Tubs("SSTshell",0.,12.5*mm,4.5*mm,0.,2*M_PI);
 G4LogicalVolume* SSTshell_Log = new G4LogicalVolume(SSTshell_Sol,steel,"Lead_shell",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,3.5*mm),SSTshell_Log ,"SSTshell",ContHole_Log,false,0,true);
 
/* G4Tubs* SSTshell_Sol = new G4Tubs("SSTshell",0.,5.*mm,0.445*mm,0.,2*M_PI);
 G4LogicalVolume* SSTshell_Log = new G4LogicalVolume(SSTshell_Sol,steel,"Lead_shell",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,0.445*mm),SSTshell_Log ,"SSTshell",worldLog,false,0);*/

 G4VisAttributes* SSTshellVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0,0.1)); 
 SSTshellVisAtt->SetForceSolid(true);
 SSTshellVisAtt->SetVisibility(true);
 SSTshell_Log->SetVisAttributes(SSTshellVisAtt);
		
////////******* source 3203 capsule ******//////////		
/*
 	// Source
	G4Tubs* source_Sol = new G4Tubs("source",0.,2.*mm,0.5*mm,0.,2*M_PI);
 	G4LogicalVolume* source_Log = new G4LogicalVolume(source_Sol,enamel,"source",0,0,0);
 	new G4PVPlacement(0,G4ThreeVector(0.,0.,0.5*mm-4.449*mm),source_Log ,"source",SSTshell_Log,false,0,true);
*/

////////******* source strontium-90 seed type Sr0.S03-1 ******//////////

	G4Tubs* groove1_Sol = new G4Tubs("groove1",0.61,2.3*mm,0.32*mm,0.,2*M_PI);
 	G4LogicalVolume* groove1_Log = new G4LogicalVolume(groove1_Sol,air,"groove1",0,0,0);
 	new G4PVPlacement(0,G4ThreeVector(0.,0.,(-4.5+0.025+0.32)*mm),groove1_Log ,"groove1",SSTshell_Log,false,0,true);

	G4Tubs* groove2_Sol = new G4Tubs("groove2",2.5,3.5*mm,0.32*mm,0.,2*M_PI);
 	G4LogicalVolume* groove2_Log = new G4LogicalVolume(groove2_Sol,air,"groove2",0,0,0);
 	new G4PVPlacement(0,G4ThreeVector(0.,0.,(-4.5+0.025+0.32)*mm),groove2_Log ,"groove2",SSTshell_Log,false,0,true);

	G4Tubs* groove3_Sol = new G4Tubs("groove3",3.7,4.7*mm,0.32*mm,0.,2*M_PI);
 	G4LogicalVolume* groove3_Log = new G4LogicalVolume(groove3_Sol,air,"groove2",0,0,0);
 	new G4PVPlacement(0,G4ThreeVector(0.,0.,(-4.5+0.025+0.32)*mm),groove3_Log ,"groove3",SSTshell_Log,false,0,true);

 G4VisAttributes* grooveVisAtt= new G4VisAttributes(G4Colour(0.0,0.0,1.0,0.1)); 
 grooveVisAtt->SetForceSolid(true);
 grooveVisAtt->SetVisibility(true);
 groove1_Log->SetVisAttributes(grooveVisAtt);
 groove2_Log->SetVisAttributes(grooveVisAtt);
 groove3_Log->SetVisAttributes(grooveVisAtt);

 	// Source canister 
	G4Tubs* sourceCan_Sol = new G4Tubs("source_canister",0.,0.32*mm,1.25*mm,0.,2*M_PI);
 	G4LogicalVolume* sourceCan_Log = new G4LogicalVolume(sourceCan_Sol,steel,"source_canister",0,0,0);

       std::vector <G4float> AngleG2; AngleG2.reserve(7); for(G4int i=0;i<7;i++)AngleG2[i]=360./7.*i*deg;
       std::vector <G4float> AngleG3; AngleG3.reserve(10); for(G4int i=0;i<10;i++)AngleG3[i]=360./10.*i*deg;
       G4float RadiusG2 = 2.92*mm;
       G4float RadiusG3 = 4.17*mm;
  
 G4VisAttributes* sourceCanVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); 
 sourceCanVisAtt->SetForceSolid(false);
 sourceCanVisAtt->SetVisibility(true);
 sourceCan_Log->SetVisAttributes(sourceCanVisAtt);

        G4RotationMatrix* rotationMatrix1 = new G4RotationMatrix();
        rotationMatrix1->rotateY(90.*deg);
 	new G4PVPlacement(rotationMatrix1,G4ThreeVector(0.,(1.25+0.32)*mm,0.),sourceCan_Log ,"source_canister",groove1_Log,false,0,true);
 	new G4PVPlacement(rotationMatrix1,G4ThreeVector(0.,(-1.)*(1.25+0.32)*mm,0.),sourceCan_Log ,"source_canister",groove1_Log,false,1,true);

        G4RotationMatrix* rotationMatrix2 = new G4RotationMatrix();
        rotationMatrix2->rotateY(90.*deg);
        rotationMatrix2->rotateX(90.*deg);
 	new G4PVPlacement(rotationMatrix2,G4ThreeVector((0.61+0.32)*mm,0.,0.),sourceCan_Log ,"source_canister",groove1_Log,false,2,true);
 	new G4PVPlacement(rotationMatrix2,G4ThreeVector((0.61+0.64+0.32)*mm,0.,0.),sourceCan_Log ,"source_canister",groove1_Log,false,3,true);
 	new G4PVPlacement(rotationMatrix2,G4ThreeVector((-1.)*(0.61+0.32)*mm,0.,0.),sourceCan_Log ,"source_canister",groove1_Log,false,4,true);
 	new G4PVPlacement(rotationMatrix2,G4ThreeVector((-1.)*(0.61+0.64+0.32)*mm,0.,0.),sourceCan_Log ,"source_canister",groove1_Log,false,5,true);

      for(G4int i=6;i<13;i++)
       {
        G4int j = i-6;
        G4RotationMatrix* rotationMatrix = new G4RotationMatrix();
        rotationMatrix->rotateY(90.*deg);
        rotationMatrix->rotateX(AngleG2[j]);
 	new G4PVPlacement(rotationMatrix,G4ThreeVector(RadiusG2*sin(AngleG2[j]),RadiusG2*cos(AngleG2[j]),0.),
	sourceCan_Log ,"source_canister",groove2_Log,false,i,true);
       } 

      for(G4int i=14;i<24;i++)
       {
        G4int j = i-14;
        G4RotationMatrix* rotationMatrix = new G4RotationMatrix();
        rotationMatrix->rotateY(90.*deg);
        rotationMatrix->rotateX(AngleG3[j]);
 	new G4PVPlacement(rotationMatrix,G4ThreeVector(RadiusG3*sin(AngleG3[j]),RadiusG3*cos(AngleG3[j]),0.),
	sourceCan_Log ,"source_canister",groove3_Log,false,i,true);
       }

 	// Source 
	G4Tubs* source_Sol = new G4Tubs("source",0.,0.28*mm,1.21*mm,0.,2*M_PI);
 	G4LogicalVolume* source_Log = new G4LogicalVolume(source_Sol,enamel,"source",0,0,0);
 	new G4PVPlacement(0,G4ThreeVector(0.,0.,0.),source_Log ,"source",sourceCan_Log,false,0,true);

 	G4VisAttributes* sourceVisAtt= new G4VisAttributes(G4Colour(1.0,0.0,0.0)); 
 	sourceVisAtt->SetForceSolid(true);
 	sourceVisAtt->SetVisibility(true);
 	source_Log->SetVisAttributes(sourceVisAtt);

 // shutter
 if(fShutter>0.)
 {
  G4Tubs* shutter_Sol = new G4Tubs("shutter",0.,15.0*mm,fShutter/2.,0.,2*M_PI);
  G4LogicalVolume* shutter_Log;
  shutter_Log = new G4LogicalVolume(shutter_Sol,steel,"shutter",0,0,0);
  new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.5*fShutter-1.0*mm),shutter_Log ,"shutter",ContHole_Log,false,0,true);

 G4VisAttributes* shutterVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); 
 shutterVisAtt->SetForceSolid(true);
 shutterVisAtt->SetVisibility(true);
 shutter_Log->SetVisAttributes(shutterVisAtt);
 }

 // SST cup
 G4Tubs* SSTcup_Sol = new G4Tubs("SSTcup",0.,4.975*mm,0.485*mm,0.,2*M_PI);
 G4LogicalVolume* SSTcup_Log = new G4LogicalVolume(SSTcup_Sol,cupMat,"SSTcup",0,0,0);
 //new G4PVPlacement(0,G4ThreeVector(0.,0.,-6.750001*mm),SSTcup_Log ,"SSTcup",worldLog,false,0,true);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,-7.515*mm),SSTcup_Log ,"SSTcup",ContHole_Log,false,0,true);

 G4VisAttributes* SSTcupVisAtt= new G4VisAttributes(G4Colour(0.5,0.5,0.5,0.25)); 
 SSTcupVisAtt->SetForceSolid(true);
 SSTcupVisAtt->SetVisibility(true);
 SSTcup_Log->SetVisAttributes(SSTcupVisAtt);

 G4Cons* cupHollow_Sol = new G4Cons("cupHollow",0.,3.975*mm,0.,4.975*mm,0.24*mm,0.,2*M_PI);
 G4LogicalVolume* cupHollow_Log = new G4LogicalVolume(cupHollow_Sol,air,"cupHollow",0,0,0);
 new G4PVPlacement(0,G4ThreeVector(0.,0.,(0.485-0.24)*mm),cupHollow_Log ,"cupHollow",SSTcup_Log,false,0,true);

 G4VisAttributes* cupHollowVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0,0.2)); 
 cupHollowVisAtt->SetForceSolid(true);
 cupHollowVisAtt->SetVisibility(true);
 cupHollow_Log->SetVisAttributes(cupHollowVisAtt);

 // grease layer

 if(fSiliconeOil>0.)
 { 
  G4Tubs* Grease_Sol = new G4Tubs("Grease",0.,Sample_diam/2.,fSiliconeOil/2.,0.,2*M_PI);
  G4LogicalVolume* Grease_Log = new G4LogicalVolume(Grease_Sol,GreaseMat,"Grease",0,0,0);
  new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm+fSiliconeOil/2.),Grease_Log ,"Grease",cupHollow_Log,false,0,true);

  G4VisAttributes* GreaseVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); 
  GreaseVisAtt->SetForceSolid(true);
  GreaseVisAtt->SetVisibility(true);
  Grease_Log->SetVisAttributes(GreaseVisAtt);
 }

 // sample div
/* G4Tubs* sample_div_Sol = new G4Tubs("sample_div",0.,Sample_diam/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log = new G4LogicalVolume(sample_div_Sol,SampleMat,"sample_div",0,0,0);*/

 G4Tubs* sample_div_Sol_1 = new G4Tubs("sample_div_1",0.*mm,1*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_1 = new G4LogicalVolume(sample_div_Sol_1,SampleMat,"sample_div_1",0,0,0);

 G4Tubs* sample_div_Sol_2 = new G4Tubs("sample_div_2",1*mm/2.,2*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_2 = new G4LogicalVolume(sample_div_Sol_2,SampleMat,"sample_div_2",0,0,0);

 G4Tubs* sample_div_Sol_3 = new G4Tubs("sample_div_3",2*mm/2.,3*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_3 = new G4LogicalVolume(sample_div_Sol_3,SampleMat,"sample_div_3",0,0,0);

 G4Tubs* sample_div_Sol_4 = new G4Tubs("sample_div_4",3*mm/2.,4*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_4 = new G4LogicalVolume(sample_div_Sol_4,SampleMat,"sample_div_4",0,0,0);

 G4Tubs* sample_div_Sol_5 = new G4Tubs("sample_div_5",4*mm/2.,5*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_5 = new G4LogicalVolume(sample_div_Sol_5,SampleMat,"sample_div_5",0,0,0);

 G4Tubs* sample_div_Sol_6 = new G4Tubs("sample_div_6",5*mm/2.,6*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_6 = new G4LogicalVolume(sample_div_Sol_6,SampleMat,"sample_div_6",0,0,0);

 G4Tubs* sample_div_Sol_7 = new G4Tubs("sample_div_7",6*mm/2.,7*mm/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_7 = new G4LogicalVolume(sample_div_Sol_7,SampleMat,"sample_div_7",0,0,0);

 G4Tubs* sample_div_Sol_8 = new G4Tubs("sample_div_8",7*mm/2.,7.95/2.,Sample_div/2.,0.,2*M_PI);
 G4LogicalVolume* sample_div_Log_8 = new G4LogicalVolume(sample_div_Sol_8,SampleMat,"sample_div_8",0,0,0);

 G4int N_ring = 8;
 G4int N_Layer=int(Sample_Thick/Sample_div);
 G4int Nb_div=N_Layer*N_ring ;

 for (G4int i =0;i<N_Layer;i++)
 {
  if(Sample_diam>0.*mm)  new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                        + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_1 ,"sample_div_1",cupHollow_Log,false,i,true);
 if(Sample_diam>1.*mm)   new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_2 ,"sample_div_2",cupHollow_Log,false,i,true);
  if(Sample_diam>2.*mm)  new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_3 ,"sample_div_3",cupHollow_Log,false,i,true);
  if(Sample_diam>3.*mm)  new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_4 ,"sample_div_4",cupHollow_Log,false,i,true);
 if(Sample_diam>4.*mm)   new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_5 ,"sample_div_5",cupHollow_Log,false,i,true);
 if(Sample_diam>5.*mm)   new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_6 ,"sample_div_6",cupHollow_Log,false,i,true);
 if(Sample_diam>6.*mm)   new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_7 ,"sample_div_7",cupHollow_Log,false,i,true);
 if(Sample_diam>7.*mm)   new G4PVPlacement(0,G4ThreeVector(0.,0.,-0.24*mm + fSiliconeOil+ 1.*nm 
                         + Sample_Thick -(i+0.5)*Sample_div),sample_div_Log_8 ,"sample_div_8",cupHollow_Log,false,i,true);
  }

 G4VisAttributes* sample_divVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,0.0)); 
 sample_divVisAtt->SetForceSolid(true);
 sample_divVisAtt->SetVisibility(true);
 sample_div_Log_1->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_2->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_3->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_4->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_5->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_6->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_7->SetVisAttributes(sample_divVisAtt);
 sample_div_Log_8->SetVisAttributes(sample_divVisAtt);
}

