//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "PrimaryGeneratorAction.hh"
#include "G4TransportationManager.hh"
#include "G4Navigator.hh"
#include "G4PathFinder.hh"

using namespace std;

PrimaryGeneratorAction::PrimaryGeneratorAction(RunAction* run):myRunAct(run)
{
 // variables initialization
 particleName = "NULL";
 ParticleCount = 0.;

 G4int n_particle = 1;
 particleGun  = new G4ParticleGun(n_particle);
  
 // default particle kinematic
 G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
 particle = particleTable->FindParticle(particleName="geantino");
 particleGun->SetParticleDefinition(particle); 
 particleGun->SetParticlePosition(G4ThreeVector(0,0,0));  
 particleGun->SetParticleMomentumDirection(G4RandomDirection());  
 particleGun->SetParticleEnergy(0.*keV);


 G4double E,P;
 G4String ColumnName;
 G4int Sdim =0;  
 SpectDim=0; 
 ifstream spect;

 spect.open(spectre,ios::in);
 if(!spect.is_open()){G4cout<<"impossible to open the emission spectrum"<<G4endl;abort();}
 Sdim = std::count(std::istreambuf_iterator<char>( spect ),std::istreambuf_iterator<char>(),'\n' );
 spect.close();
 
 energy.reserve(Sdim);energy[0]=0;
 proba.reserve(Sdim);proba[0]=0;

 spect.open(spectre,ios::in);
 spect>>ColumnName>>ColumnName;spect.ignore(100,'\n');
 for(G4int i=1; i<Sdim;i++)
 {
  spect>>E>>P;spect.ignore(100,'\n');
  energy[i]=E;
  proba[i]=P;
 }
 spect.close();
 SpectDim = Sdim-1;

}

PrimaryGeneratorAction::~PrimaryGeneratorAction()
{ 
 delete particleGun;
}


void PrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
{ 
 static G4ParticleTable* particleTable;
 if(!particleTable) particleTable = G4ParticleTable::GetParticleTable();


  static G4Navigator* Navigator = 0;

    static G4PathFinder* pPathFinder = G4PathFinder::GetInstance();

    if(!Navigator)
    {

      G4String WName = "World";
      G4VPhysicalVolume * World =G4TransportationManager::GetTransportationManager()->IsWorldExisting(WName);

      Navigator =
        G4TransportationManager::GetTransportationManager()
        ->GetNavigator(World);
    }

    G4int navigatorID = G4TransportationManager::GetTransportationManager()->ActivateNavigator(Navigator);

 // select a random position in the source


////////******* source 3203 capsule ******//////////
 G4float SourceDiam = 4.0*mm;
 G4float SourceThick = 1.0*mm;
 G4float sourceZ = (0.051+0.5)*mm;

////////******* source strontium-90 seed type Sr0.S03-1 ******//////////
/* G4float SourceDiam = 2.0*4.7*mm;
 G4float SourceThick = 0.64*mm;
 G4float sourceZ = (0.025+0.32)*mm;
*/

 G4float PosX = SourceDiam*(G4UniformRand()-0.5);
 G4float PosY = SourceDiam*(G4UniformRand()-0.5);
 G4float PosZ = SourceThick*(G4UniformRand()-0.5) + sourceZ;

 G4ThreeVector position(PosX,PosY,PosZ);
 G4ThreeVector momDirection(G4UniformRand(),G4UniformRand(),G4UniformRand());

    pPathFinder->PrepareNewTrack(position,momDirection);
    pPathFinder->Locate(position,momDirection,true);

    Vol =  pPathFinder-> GetLocatedVolume(navigatorID);
    
  while(Vol->GetName()!="source")
 {

  PosX = SourceDiam*(G4UniformRand()-0.5);
  PosY = SourceDiam*(G4UniformRand()-0.5);
  PosZ = SourceThick*(G4UniformRand()-0.5) + sourceZ;
  position=G4ThreeVector(PosX,PosY,PosZ);
  pPathFinder->PrepareNewTrack(position,momDirection);
  pPathFinder->Locate(position,momDirection,true);
  Vol =  pPathFinder-> GetLocatedVolume(navigatorID);
 }

 //G4ThreeVector position(PosX/2.-5.*mm,PosY/2.-5.*mm,PosZ);
 //G4ThreeVector position(-5.*mm,-5.*mm,PosZ);
/*
  // Set particle gun   
 //if (particleGun->GetParticleDefinition() == G4Geantino::Geantino()) {  
    G4int Z = 38, A = 90;
    //G4int Z = 6, A = 12;
    G4double ionCharge   = 0.*eplus;
    G4double excitEnergy = 0.*keV;
    
    G4ParticleDefinition* ion
       = G4IonTable::GetIonTable()->GetIon(Z,A,excitEnergy);
    particleGun->SetParticleDefinition(ion);
    particleGun->SetParticleCharge(ionCharge);

*/

 G4double j = G4UniformRand();
 G4int k_min = 0;
 G4int k_max = SpectDim;
 G4int k = 0;
 Energy=0;
 
 while(k_max-k_min>1)
 { 
  k = (int) ((k_min+k_max)/2.) ;
  if (proba[k] < j){k_min = k;}
  else {k_max = k;}
 }
 Energy=energy[k_max]*keV;
 
  particle = particleTable->FindParticle(particleName="e-");

    particleGun->SetParticleEnergy(Energy); 
    particleGun->SetParticleDefinition(particle);
    particleGun->SetParticlePosition(position);
    particleGun->SetParticleMomentumDirection(G4RandomDirection());
//}
  
  //create vertex
  //   
  particleGun->GeneratePrimaryVertex(anEvent); // emission of the particle
  ParticleCount += 1.;
  
  G4int ThousandPart = ParticleCount%10000;
  if(ThousandPart == 0)
  {
   G4cout<<'\r'<<"\033[K"<<"Nb of particles simulated: "<<ParticleCount;
   G4cout.flush() ;
  }




 
    
}

